summaryrefslogtreecommitdiff
path: root/gst/gstpad.c
diff options
context:
space:
mode:
Diffstat (limited to 'gst/gstpad.c')
-rw-r--r--gst/gstpad.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/gst/gstpad.c b/gst/gstpad.c
index f9822ea559..ba96ff2677 100644
--- a/gst/gstpad.c
+++ b/gst/gstpad.c
@@ -3384,8 +3384,8 @@ probe_hook_marshal (GHook * hook, ProbeMarshall * data)
type = info->type;
original_data = info->data;
- /* one of the data types for non-idle probes */
- if ((type & GST_PAD_PROBE_TYPE_IDLE) == 0
+ /* one of the data types for non-idle, non-pull probes */
+ if ((type & (GST_PAD_PROBE_TYPE_IDLE | GST_PAD_PROBE_TYPE_PULL)) == 0
&& (flags & GST_PAD_PROBE_TYPE_ALL_BOTH & type) == 0)
goto no_match;
/* one of the scheduling types */